changeset 111330:651ebb81e47d

Fix the most annoying typo in the world. * lisp/play/gomoku.el (gomoku-loosing-threshold): Correct spelling. (gomoku-human-plays): Use new name.
author Glenn Morris <rgm@gnu.org>
date Tue, 02 Nov 2010 20:33:24 -0700
parents be0bea620615
children f3a306e9418e
files lisp/ChangeLog lisp/play/gomoku.el
diffstat 2 files changed, 7 insertions(+), 4 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/ChangeLog	Tue Nov 02 20:30:37 2010 -0700
+++ b/lisp/ChangeLog	Tue Nov 02 20:33:24 2010 -0700
@@ -1,5 +1,8 @@
 2010-11-03  Glenn Morris  <rgm@gnu.org>
 
+	* play/gomoku.el (gomoku-loosing-threshold): Correct spelling.
+	(gomoku-human-plays): Use new name.
+
 	* play/gomoku.el (nil-score, Xscore, XXscore, XXXscore, XXXXscore)
 	(Oscore, OOscore, OOOscore, OOOOscore): Rename with gomoku- prefix.
 	(gomoku-score-trans-table, gomoku-winning-threshold)
--- a/lisp/play/gomoku.el	Tue Nov 02 20:30:37 2010 -0700
+++ b/lisp/play/gomoku.el	Tue Nov 02 20:33:24 2010 -0700
@@ -278,7 +278,7 @@
 ;; its contents as a set, i.e. not considering the order of its elements. The
 ;; highest score is given to the "OOOO" qtuples because playing in such a
 ;; qtuple is winning the game. Just after this comes the "XXXX" qtuple because
 ;; not playing in it is just loosing the game, and so on. Note that a
 ;; "polluted" qtuple, i.e. one containing at least one X and at least one O,
 ;; has score zero because there is no more any point in playing in it, from
 ;; both an attacking and a defending point of view.
@@ -348,12 +348,12 @@
 ;; qtuple, thus to be a winning move. Similarly, the only way for a square to
 ;; have a score between gomoku-XXXXscore and gomoku-OOOOscore is to belong to a "XXXX"
 ;; qtuple. We may use these considerations to detect when a given move is
 ;; winning or loosing.
 
 (defconst gomoku-winning-threshold gomoku-OOOOscore
   "Threshold score beyond which an Emacs move is winning.")
 
-(defconst gomoku-loosing-threshold gomoku-XXXXscore
+(defconst gomoku-losing-threshold gomoku-XXXXscore
   "Threshold score beyond which a human move is winning.")
 
 
@@ -872,7 +872,7 @@
 	    (t
 	     (setq score (aref gomoku-score-table square))
 	     (gomoku-play-move square 1)
-	     (cond ((and (>= score gomoku-loosing-threshold)
+	     (cond ((and (>= score gomoku-losing-threshold)
 			 ;; Just testing SCORE > THRESHOLD is not enough for
 			 ;; detecting wins, it just gives an indication that
 			 ;; we confirm with GOMOKU-FIND-FILLED-QTUPLE.
@@ -278,7 +278,7 @@
 ;; highest score is given to the "OOOO" qtuples because playing in such a
 ;; qtuple is winning the game. Just after this comes the "XXXX" qtuple because
-;; not playing in it is just loosing the game, and so on. Note that a
+;; not playing in it is just losing the game, and so on. Note that a
 ;; "polluted" qtuple, i.e. one containing at least one X and at least one O,
 ;; has score zero because there is no more any point in playing in it, from
@@ -348,12 +348,12 @@
 ;; have a score between gomoku-XXXXscore and gomoku-OOOOscore is to belong to a "XXXX"
 ;; qtuple. We may use these considerations to detect when a given move is
-;; winning or loosing.
+;; winning or losing.
 
 (defconst gomoku-winning-threshold gomoku-OOOOscore